#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Same as RG but used for nonstroking operations.
"""
from decimal import Decimal
from typing import List

from borb.io.read.types import AnyPDFType
from borb.pdf.canvas.color.color import RGBColor
from borb.pdf.canvas.operator.canvas_operator import CanvasOperator


class SetRGBNonStroking(CanvasOperator):
    """
    Same as RG but used for nonstroking operations.
    """

    def __init__(self):
        super().__init__("rg", 3)

    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
        """
        Invoke the rg operator
        """
        assert isinstance(
            operands[0], Decimal
        ), "operand 0 of rg operator must be of type Decimal"
        assert isinstance(
            operands[1], Decimal
        ), "operand 1 of rg operator must be of type Decimal"
        assert isinstance(
            operands[2], Decimal
        ), "operand 2 of rg operator must be of type Decimal"
        r = operands[0]
        g = operands[1]
        b = operands[2]
        canvas = canvas_stream_processor.get_canvas()
        canvas.graphics_state.non_stroke_color = RGBColor(r, g, b)
